;
; Init Routines
;
; Copyright 2002 by Thorsten Klose
; Commercial use without my permission is strictly forbidden!
;


Init
	movf	PCLATH, W	; store pointer to both condition tables
	iorlw	0x07
	movwf	PCLATH

	SWITCHBANK_0_1
	movlw	0x7f		; Prescaler for Watchdog, Max Prescaling, Enable PullUps on PortB, 
	movwf	OPTION_REG	; Interrupt on falling Edge @ RA4, Timer0 Enabled
	SWITCHBANK_1_0

	call	Init_Ports
	call	Init_USART
	call	Init_MIDI

#if 0
	IFCLR	STATUS, NOT_TO, call Malfunction_Message ; On WDT Reset print Malfunction Message
#endif

	call	Init_IRQ

	return

;; ==========================================================================


;; --------------------------------------------------------------------------
;;  Init Routine for Ports
;; --------------------------------------------------------------------------
Init_Ports
	clrf	PORTA
	clrf	PORTB			; Reset PortB
	movlw	0x40			; Reset PortC (TX Pin = 1)
	movwf	PORTC
	clrf	PORTD			; Reset PortD
	clrf	PORTE			; Reset PortE
	
	SWITCHBANK_0_1

	movlw	TRISA_VALUE
	movwf	TRISA
	movlw	TRISB_VALUE
	movwf	TRISB
	movlw	TRISC_VALUE
	movwf	TRISC
	movlw	TRISD_VALUE
	movwf	TRISD
	movlw	TRISE_VALUE
	movwf	TRISE

	movlw	0x07			; PortA and E: All Pins are digital pins
	movwf	ADCON1

	SWITCHBANK_1_0

	return

;; ==========================================================================
;;  Initialization Routine for IRQ Handler
;; ==========================================================================
Init_IRQ
	SWITCHBANK_0_1

        movlw   (1 << RCIE)		; enable UART Receive IRQ
        movwf   PIE1
        clrf    PIE2                    ; clear all other IRQs

	SWITCHBANK_1_0

        bcf     RCSTA, CREN
        movf    RCREG, W
        bsf     RCSTA, CREN
                
        ; enable maskable IRQs
        movlw   (1 << GIE) | (1 << PEIE)
        movwf   INTCON

        return

;; --------------------------------------------------------------------------
;;  Init Routine for USART
;; --------------------------------------------------------------------------
Init_USART
	SWITCHBANK_0_1
	movlw	(1 << TXEN)	; set baudrate:	31250
	movwf	TXSTA
  	movlw	0x09
	movwf	SPBRG
	SWITCHBANK_1_0

	; Configure Receive Status and Control Register
	movlw	(1 << SPEN) | (1 << CREN)
	movwf	RCSTA

	movlw	RINGBUFFER0
	movwf	RINGBUFFER0_A
	movwf	RINGBUFFER0_B
	
	return


;; --------------------------------------------------------------------------
;;  Init Routine for MIDI
;; --------------------------------------------------------------------------
Init_MIDI
	clrf	MIDI0_RUNSTATUS
	clrf	MIDI_EXPBYTES
	clrf	MIDI_FxSTATUS
	return
