;
; Macro Definitions
;
; Copyright 1999, 2000 by Thorsten Klose
; Commercial use without my permission is strictly forbidden!
;

;; ==========================================================================
;;  Macros
;; ==========================================================================

IFSET	MACRO	reg, bit, instr
	btfsc	reg, bit
	instr
	ENDM


IFCLR	MACRO	reg, bit, instr
	btfss	reg, bit
	instr
	ENDM

;; ==========================================================================

WEQ     MACRO   value, instr    ; do something if W == value
        xorlw   value
        skpnz
        instr
        ENDM

WGT     MACRO  value, instr     ; do something if W > value
        sublw   value
        skpc
        instr
        ENDM

WLTEQ   MACRO  value, instr     ; do something if W <= value
        sublw   value
        skpnc
        instr
        ENDM
	
;; ==========================================================================

DATA_IN MACRO
        bsf     STATUS, RP0     ; switch to Bank 1
        movlw   0xff
        movwf   TRIS_LCD_D
        bcf     STATUS, RP0     ; switch to Bank 0
        ENDM

DATA_OUT MACRO
        bsf     STATUS, RP0     ; switch to Bank 1
        clrf    TRIS_LCD_D
        bcf     STATUS, RP0     ; switch to Bank 0
        ENDM

LCD_STROBE MACRO
        bsf     PORT_LCD_E, E
	nop
	nop
        bcf     PORT_LCD_E, E
        ENDM


LCD_WRITE MACRO
        bcf     PORT_LCD_RW, RW
        ENDM

LCD_READ MACRO
        bsf     PORT_LCD_RW, RW
        ENDM

LCD_RS_0 MACRO
        bcf     PORT_LCD_RS, RS
        ENDM

LCD_RS_1 MACRO
        bsf     PORT_LCD_RS, RS
        ENDM

;; ==========================================================================

IRQ_DISABLE MACRO
        local   loop
loop:
        bcf     INTCON, GIE
        IFSET   INTCON, GIE, goto loop
        ENDM

IRQ_ENABLE MACRO
        bsf     INTCON, GIE
        ENDM

;; ==========================================================================
        
FLASH_ADDR MACRO addr
	SWITCHBANK_0_2
	movlw	(addr & 0xff)	; store Lo Byte
	movwf	EEADR
	movlw	(addr >> 8)	; store Hi Byte
	movwf	EEADRH
	SWITCHBANK_2_0
	ENDM

FLASH_H	MACRO	addr
	SWITCHBANK_0_2
	movlw	(addr >> 8)	; store Hi Byte
	movwf	EEADRH
	SWITCHBANK_2_0
	ENDM

FLASH_WH MACRO
	SWITCHBANK_0_2
	movwf	EEADRH
	SWITCHBANK_2_0
	ENDM

FLASH_L	MACRO	addr
	SWITCHBANK_0_2
	movlw	(addr & 0xff)	; store Lo Byte
	movwf	EEADR
	SWITCHBANK_2_0
	ENDM

FLASH_WL MACRO
	SWITCHBANK_0_2
	movwf	EEADR
	SWITCHBANK_2_0
	ENDM

;; ==========================================================================

SWITCHBANK_0_1 MACRO
        bsf     STATUS, RP0
        ENDM
SWITCHBANK_0_2 MACRO
        bsf     STATUS, RP1
        ENDM
SWITCHBANK_0_3 MACRO
        bsf     STATUS, RP0
        bsf     STATUS, RP1
        ENDM

SWITCHBANK_1_0 MACRO
        bcf     STATUS, RP0
        ENDM
SWITCHBANK_1_2 MACRO
        bcf     STATUS, RP0
        bsf     STATUS, RP1
        ENDM
SWITCHBANK_1_3 MACRO
        bsf     STATUS, RP1
        ENDM

SWITCHBANK_2_0 MACRO
        bcf     STATUS, RP1
        ENDM
SWITCHBANK_2_1 MACRO
        bsf     STATUS, RP0
        bcf     STATUS, RP1
        ENDM
SWITCHBANK_2_3 MACRO
        bsf     STATUS, RP0
        ENDM

SWITCHBANK_3_0 MACRO
        bcf     STATUS, RP0
        bcf     STATUS, RP1
        ENDM
SWITCHBANK_3_1 MACRO
        bcf     STATUS, RP1
        ENDM
SWITCHBANK_3_2 MACRO
        bcf     STATUS, RP0
        ENDM

;; ==========================================================================

SWITCHPAGE_0 MACRO
	bcf	PCLATH, 3
	ENDM

SWITCHPAGE_1 MACRO
	bsf	PCLATH, 3
	ENDM

SWITCHPAGE_U MACRO
	bsf	PCLATH, 4
	ENDM

SWITCHPAGE_L MACRO
	bcf	PCLATH, 4
	ENDM

;; ==========================================================================

SWITCH_FSR_LOWER MACRO
        bcf     STATUS, IRP
        ENDM

SWITCH_FSR_UPPER MACRO
        bsf     STATUS, IRP
        ENDM

;; ==========================================================================

DEBUG_LOW MACRO
#if DEBUG_MODE == 1
	bcf	PORT_DEBUG, PIN_DEBUG
#endif
	ENDM

DEBUG_HIGH MACRO
#if DEBUG_MODE == 1
	bsf	PORT_DEBUG, PIN_DEBUG
#endif
	ENDM

;; ==========================================================================

XGOTO MACRO label
        if label & 0x800
        SWITCHPAGE_1
        else
        SWITCHPAGE_0
        endif
        goto    label
        ENDM

XCALL MACRO label
        LOCAL   testlabel
testlabel:
        if label & 0x800
        SWITCHPAGE_1
        else
        SWITCHPAGE_0
        endif

        call    label

        if testlabel & 0x800
        SWITCHPAGE_1
        else
        SWITCHPAGE_0
        endif

        ENDM

XXCALL MACRO label
	LOCAL	testlabel
testlabel:
	if label & 0x800
	SWITCHPAGE_1
	else
	SWITCHPAGE_0
	endif
	if label & 0x1000
	SWITCHPAGE_U
	else
	SWITCHPAGE_L
	endif

	call	label

	if testlabel & 0x800
	SWITCHPAGE_1
	else
	SWITCHPAGE_0
	endif
	if testlabel & 0x1000
	SWITCHPAGE_U
	else
	SWITCHPAGE_L
	endif
	ENDM

XXGOTO MACRO label
	LOCAL	testlabel
testlabel:
	if label & 0x800
	SWITCHPAGE_1
	else
	SWITCHPAGE_0
	endif
	if label & 0x1000
	SWITCHPAGE_U
	else
	SWITCHPAGE_L
	endif

	goto	label

	ENDM

