;
; General Definitions
;
; Copyright 2002 by Thorsten Klose
; Commercial use without my permission is strictly forbidden!
;

 
;; ==========================================================================
;;  Assembler & PICstart directives
;; ==========================================================================

#ifdef __16F877
#include <p16f877.inc>
	LIST P=PIC16F877, R=DEC
#else
#include <p16f874.inc>
	LIST P=PIC16F874, R=DEC
#endif
	
        ERRORLEVEL      -302    ; SUPPRESS BANK SELECTION MESSAGES
        ERRORLEVEL      -307    ; SUPPRESS PCLATH SELECTION MESSAGES
        ERRORLEVEL      -306    ; SUPPRESS PCLATH SELECTION MESSAGES

;; ==========================================================================
;;  Some Flags
;; ==========================================================================

#define PROTECTED_MODE	0
#define DEBUG_MODE	1

;; ==========================================================================
;;  Chip Configuration
;; ==========================================================================

#if PROTECTED_MODE == 1
        __CONFIG _HS_OSC & _WDT_OFF & _PWRTE_ON & _CP_HALF & _BODEN_ON & _LVP_OFF
#else
        __CONFIG _HS_OSC & _WDT_OFF & _PWRTE_ON & _CP_OFF & _BODEN_ON & _LVP_OFF
#endif

;; ==========================================================================
;;  Ports
;; ==========================================================================

; My "debug pin" to measure execution times on the scope (used by the DEBUG_LOW/DEBUG_HIGH macros)
PORT_DEBUG	EQU	PORTC
PIN_DEBUG	EQU	4

TRISA_VALUE	EQU	b'00010000'	; Setup Value for Tristate Drivers of PortA
TRISE_VALUE	EQU	b'00000000'	; Setup Value for Tristate Drivers of PortE
TRISB_VALUE	EQU	b'00000000'	; Setup Value for Tristate Drivers of PortB
TRISC_VALUE	EQU	b'10000000'	; Setup Value for Tristate Drivers of PortC
TRISD_VALUE	EQU	b'00000000'	; Setup Value for Tristate Drivers of PortD


;; ==========================================================================
;;  Status Bytes & Bits
;; ==========================================================================


;; ==========================================================================
;;  Register File
;; ==========================================================================

RINGBUFFER0_A	EQU	0x20
RINGBUFFER0_B	EQU	0x21

MIDI_TIMEOUT_LOW EQU    0x22
MIDI_TIMEOUT_HIGH EQU   0x23
MIDI_TIMEOUT_HHIGH EQU  0x24
MIDI_IN         EQU     0x25
MIDI_EXPBYTES	EQU	0x26
MIDI0_RUNSTATUS	EQU	0x27
MIDI_LASTEVENT0 EQU     0x28
MIDI_LASTEVENT1 EQU     0x29
MIDI_LASTEVENT2 EQU     0x2a
MIDI_FxSTATUS   EQU     0x2b

;; 0x30-0x7b: SUART IN Ringbuffer
RINGBUFFER0     EQU     0x30
RINGBUFFER0_END	EQU	0x7b

TMP1            EQU     0x7c
FSR_TMP		EQU	0x7d
STATUS_TMP	EQU	0x7e
W_TMP		EQU	0x07f
W_TMP2		EQU	0x0ff
W_TMP3		EQU	0x17f
W_TMP4		EQU	0x1ff

;; ==========================================================================
